import * as React from "react";
import { OnPressFunction } from "./Hooks/touchable-hook";
export type ButtonSize = "xs" | "sm" | "md" | "lg" | "xl";
export declare const getHeight: (size: ButtonSize) => "25px" | "30px" | "48px" | "60px" | "40px";
export declare function focusShadow(first: string, second: string, third: string): string;
export declare const buttonReset: import("@emotion/utils").SerializedStyles;
export type ButtonIntent = "none" | "warning" | "primary" | "success" | "danger";
declare const variants: {
    default: import("@emotion/utils").SerializedStyles;
    ghost: import("@emotion/utils").SerializedStyles;
    outline: import("@emotion/utils").SerializedStyles;
};
export type ButtonVariant = keyof typeof variants;
export interface ButtonStyleProps {
    /** Use onPress instead of onClick to handle both touch and click events */
    onPress?: OnPressFunction;
    /** Controls the basic button style. */
    variant?: ButtonVariant;
    /** Controls the colour of the button. */
    intent?: ButtonIntent;
    /** If true, the button will be displayed as a block element instead of inline. */
    block?: boolean;
    /** The size of the button. */
    size?: ButtonSize;
    /** Show a loading indicator */
    loading?: boolean;
    disabled?: boolean;
    /** The name of the icon to appear to the left of the button text*/
    iconBefore?: React.ReactNode;
    /** The name of the icon to appear to the right of the button text */
    iconAfter?: React.ReactNode;
    /** By default, a button element will only highlight after a short
     * delay to prevent unintended highlights when scrolling. You can set this to
     * 0 if the element is not in a scrollable container */
    pressDelay?: number;
    /**
     * By default, a touchable element will have an expanded press area of 20px
     * on touch devices. This will only effect touch devices.
     */
    pressExpandPx?: number;
}
export interface ButtonProps extends ButtonStyleProps, React.ButtonHTMLAttributes<HTMLButtonElement> {
    children: React.ReactNode;
    ref?: React.Ref<HTMLButtonElement>;
    component?: React.ElementType<any>;
    noBind?: boolean;
    /** Whether active presses should be terminated when scrolling occurs. Typically this should be true.
     * 跳转页面后,滚动爆出 unmounted 错误
     * 原先默认是terminateOnScroll=true, 这里改成可用参数重载它,默认改成=false；
     * */
    terminateOnScroll?: boolean;
    [key: string]: any;
}
/**
 * Your standard Button element
 * 新版本Button 不能传入ref; 若需要控制捕捉,ref传递的，请用ButtonRefComp;
 */
export declare const Button: React.FunctionComponent<ButtonProps>;
/**
 * 旧版本 可支持传入 ref 控制参数的。
 * ButtonRefComp 比起 Button多个 ref需要绑定。 其余代码完全一致
 */
export declare const ButtonRefComp: React.ForwardRefExoticComponent<Pick<ButtonProps, keyof ButtonProps> & React.RefAttributes<any>>;
/**新的点击触发按的组件： 去掉useTouchable 改成onClick()
 */
export declare const Button2Comp: React.ForwardRefExoticComponent<Pick<ButtonProps, keyof ButtonProps> & React.RefAttributes<any>>;
export {};
